summaryrefslogtreecommitdiffstats
path: root/lib/public/share.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/public/share.php')
-rw-r--r--lib/public/share.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/lib/public/share.php b/lib/public/share.php
index 564839e86b6..c694314ad08 100644
--- a/lib/public/share.php
+++ b/lib/public/share.php
@@ -64,14 +64,15 @@ class Share extends \OC\Share\Constants {
/**
* Find which users can access a shared item
* @param string $path to the file
* @param string $user owner of the file
* @param bool $includeOwner include owner to the list of users with access to the file
+ * @param bool $returnUserPaths Return an array with the user => path map
* @return array
* @note $path needs to be relative to user data dir, e.g. 'file.txt'
* not '/admin/data/file.txt'
*/
- public static function getUsersSharingFile($path, $user, $includeOwner = false) {
- return \OC\Share\Share::getUsersSharingFile($path, $user, $includeOwner);
+ public static function getUsersSharingFile($path, $ownerUser, $includeOwner = false, $returnUserPaths = false) {
+ return \OC\Share\Share::getUsersSharingFile($path, $ownerUser, $includeOwner, $returnUserPaths);
}
/**
@@ -64,14 +64,15 @@ class Share extends \OC\Share\Constants {
* Find which users can access a shared item
* @param string $path to the file
- * @param string $user owner of the file
+ * @param string $ownerUser owner of the file
* @param bool $includeOwner include owner to the list of users with access to the file